import numpy as np
import matplotlib.pyplot as plt
from astropy.table import Table
from uncertainties import ufloat
from matplotlib.transforms import ScaledTranslation
import matplotlib.ticker as ticker

oc_fn = 'member_cz30.txt'
field_fn = 'field_cz30.txt'
iso_bv_fn = 'ma/m-0.220_age9.450.txt'
iso_vi_fn = 'ma/m-0.220_age9.450.txt'

dat = Table.read(oc_fn, format='ascii')
field_dat = Table.read(field_fn, format='ascii')
BV = dat['B'] - dat['V']
V = dat['V']
I = dat['I']
field_BV = field_dat['B'] - field_dat['V']
field_VI = field_dat['V'] - field_dat['I']
field_V = field_dat['V']
field_I = field_dat['I']

bv_fit_iso_B0, bv_fit_iso_V0 = np.genfromtxt(iso_bv_fn, usecols=(2,3), skip_header=3, unpack=True)
vi_fit_iso_V0, vi_fit_iso_I0 = np.genfromtxt(iso_vi_fn, usecols=(3,5), skip_header=3, unpack=True)

# just for text aboutGaussianMixture isochrone model information on CMD
bv_a0 = iso_bv_fn.split('_')[0]
bv_b0 = iso_bv_fn.split('_')[1]
bv_aa0 = float(bv_a0.split('a/m')[1]) # metallicity
bv_bbb0 = bv_b0.split('e')[1]
bv_bb0 = float(bv_bbb0.split('.i')[0]) # age

vi_a0 = iso_vi_fn.split('_')[0]
vi_b0 = iso_vi_fn.split('_')[1]
vi_aa0 = float(vi_a0.split('a/m')[1])
vi_bbb0 = vi_b0.split('e')[1]
vi_bb0 = float(vi_bbb0.split('.i')[0])

# -----------------------------------------------------------
# V VS B-V CMD
bv_fit_dismod = 14.05
bv_fit_ebv = 0.15

bv_dismod_err = 0.13
bv_ebv_err = 0.08

bv_fit_dismodb = bv_fit_dismod + 4.14*bv_fit_ebv
bv_fit_dismodv = bv_fit_dismod + 3.10*bv_fit_ebv

bv_fit_isoBV0 = bv_fit_iso_B0 - bv_fit_iso_V0
bv_fit_isoBV = bv_fit_isoBV0 + bv_fit_ebv

bv_fit_isoB = bv_fit_iso_B0 + bv_fit_dismodb
bv_fit_isoV = bv_fit_iso_V0 + bv_fit_dismodv

# -----------------------------------------------------------
# V VS V-I CMD
vi_fit_dismod = 14.05
vi_fit_ebv = 0.18
vi_fit_evi = vi_fit_ebv*1.4

vi_dismod_err = 0.13
vi_ebv_err = 0.08

u_ebv = ufloat(vi_fit_ebv, vi_ebv_err)
u_evi = u_ebv*1.4

vi_fit_dismodv = vi_fit_dismod + 3.10*vi_fit_ebv
vi_fit_dismodi = vi_fit_dismod + 1.48*vi_fit_ebv

vi_fit_isoVI0 = vi_fit_iso_V0 - vi_fit_iso_I0
vi_fit_isoVI = vi_fit_isoVI0 + vi_fit_evi

vi_fit_isoV = vi_fit_iso_V0 + vi_fit_dismodv
vi_fit_isoI = vi_fit_iso_I0 + vi_fit_dismodi

# -----------------------------------------------------------
# Red clump

RC = np.squeeze(np.array([np.where(dat['ID'] == 3779),np.where(dat['ID'] == 3800),np.where(dat['ID'] == 4128)]))
arr = np.ones(len(BV), dtype=bool)
arr[RC] = False

# -----------------------------------------------------------
fig = plt.figure(figsize=(7,16))
ax = fig.add_subplot(211)

ax.set_ylim((20.5, 14))
ax.set_xlim((0.0, 2.))
ax.plot(field_BV, field_V, color='gray', ls='none', marker='.', alpha=0.3)
ax.plot(BV[arr], V[arr], mec='k', mew=1, mfc='none', ls='none', marker='o', ms=5, alpha=0.7)
ax.plot(BV[RC], V[RC], mec='b', mew=1.2, mfc='none', ls='none', marker='o', ms=5.5)
ax.plot(bv_fit_isoBV, bv_fit_isoV, color='r')
ax.text(0.02,0.95, '(a)', fontsize=16, transform=ax.transAxes)
ax.text(0.09, 0.81,
        '$\log t = {0:.2f} \pm 0.05$\n[Fe/H] $= {1:.2f} \pm 0.10$\n(m$-$M)$_0 = {2:.2f} \pm {3:.2f}$\nE($B-V) = {4:.2f} \pm {5:.2f}$'
        .format(float(bv_bb0), bv_aa0, bv_fit_dismod, bv_dismod_err, bv_fit_ebv, bv_ebv_err), fontsize=16, transform=ax.transAxes)

ax.set_ylabel('V', fontsize=18)
ax.set_xlabel('B - V', fontsize=18)
ax.tick_params(labelsize=16)
loc = ticker.MultipleLocator(base=0.2)
ax.xaxis.set_major_locator(loc)

ax1 = fig.add_subplot(212)

ax1.plot(field_V-field_I, field_V, color='gray', ls='none', marker='.', alpha=0.3)
ax1.plot(V[arr]-I[arr], V[arr], mec='k', mew=1, mfc='none', ls='none', marker='o', ms=5, alpha=0.7)
ax1.plot(V[RC]-I[RC], V[RC], mec='b', mew=1.2, mfc='none', ls='none', marker='o', ms=5.5)
ax1.plot(vi_fit_isoVI, vi_fit_isoV, color='r')
ax1.tick_params(labelsize=16)
ax1.text(0.02, 0.95, '(b)', fontsize=16, transform=ax1.transAxes)
ax1.text(0.09, 0.81,
        '$\log t = {0:.2f} \pm 0.05$\n[Fe/H] $= {1:.2f} \pm 0.10$\n(m$-$M)$_0 = {2:.2f} \pm {3:.2f}$\nE$(V-I) = {4:.2f} \pm {5:.2f}$'
        .format(vi_bb0, vi_aa0, vi_fit_dismod, vi_dismod_err, vi_fit_evi, u_evi.s), fontsize=16, transform=ax1.transAxes)

ax1.set_ylim((20.5, 14))
ax1.set_xlim((0.0, 2.))
ax1.set_ylabel('V', fontsize=18)
ax1.set_xlabel('V - I', fontsize=18)
ax1.xaxis.set_major_locator(loc)
#plt.savefig('cz30_iso_comb.pdf')
